import * as T from "../generated/types.js";
import { RawClient } from "../generated/client.js";
import { Event } from "../generated/events.js";
import { WebsocketTransport, BaseTransport } from "yerpc";
import { TinyEmitter } from "@deltachat/tiny-emitter";
type Events = {
    ALL: (accountId: number, event: Event) => void;
} & {
    [Property in Event["type"]]: (accountId: number, event: Extract<Event, {
        type: Property;
    }>) => void;
};
type ContextEvents = {
    ALL: (event: Event) => void;
} & {
    [Property in Event["type"]]: (event: Extract<Event, {
        type: Property;
    }>) => void;
};
export type DcEvent = Event;
export type DcEventType<T extends Event["type"]> = Extract<Event, {
    type: T;
}>;
export declare class BaseDeltaChat<Transport extends BaseTransport<any>> extends TinyEmitter<Events> {
    transport: Transport;
    rpc: RawClient;
    account?: T.Account;
    private contextEmitters;
    constructor(transport: Transport);
    listAccounts(): Promise<T.Account[]>;
    getContextEvents(account_id: number): TinyEmitter<ContextEvents>;
}
export type Opts = {
    url: string;
};
export declare const DEFAULT_OPTS: Opts;
export declare class DeltaChat extends BaseDeltaChat<WebsocketTransport> {
    opts: Opts;
    close(): void;
    constructor(opts?: Opts | string);
}
export declare class StdioDeltaChat extends BaseDeltaChat<StdioTransport> {
    close(): void;
    constructor(input: any, output: any);
}
export declare class StdioTransport extends BaseTransport {
    input: any;
    output: any;
    constructor(input: any, output: any);
    _send(message: any): void;
}
export {};
